==========================
The ``lino-amici`` package
==========================




Lino Amici is a customizable Lino application for managing family
contacts.  It is currently a submarine project, used only by its
author and therefore poorly documented.

- The central project homepage is http://amici.lino-framework.org

- For *introductions* and *commercial information* about Lino Amici
  please see `www.saffre-rumma.net
  <http://www.saffre-rumma.net>`__.



